Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(464)

Unified Diff: Source/core/html/canvas/WebGLExtension.h

Issue 24096029: Moved the majority of WebGL functionality into WebGLRenderingContextBase (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Revamped extension testing, added featureLevel Created 7 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/html/canvas/WebGLExtension.h
diff --git a/Source/core/html/canvas/WebGLExtension.h b/Source/core/html/canvas/WebGLExtension.h
index 4028906fb04ad351e714a304e69cf9ed28e50e4f..9769492d5f9d20eef2fb1457a67c8be67eda05c9 100644
--- a/Source/core/html/canvas/WebGLExtension.h
+++ b/Source/core/html/canvas/WebGLExtension.h
@@ -26,7 +26,8 @@
#ifndef WebGLExtension_h
#define WebGLExtension_h
-#include "core/html/canvas/WebGLRenderingContext.h"
+#include "core/html/canvas/WebGLExtensionNames.h"
+#include "core/html/canvas/WebGLRenderingContextBase.h"
#include "wtf/RefCounted.h"
namespace WebCore {
@@ -34,36 +35,14 @@ namespace WebCore {
class WebGLExtension : public RefCounted<WebGLExtension> {
WTF_MAKE_FAST_ALLOCATED;
public:
- // Extension names are needed to properly wrap instances in JavaScript objects.
- enum ExtensionName {
- ANGLEInstancedArraysName,
- EXTFragDepthName,
- EXTTextureFilterAnisotropicName,
- OESElementIndexUintName,
- OESStandardDerivativesName,
- OESTextureFloatLinearName,
- OESTextureFloatName,
- OESTextureHalfFloatLinearName,
- OESTextureHalfFloatName,
- OESVertexArrayObjectName,
- WebGLCompressedTextureATCName,
- WebGLCompressedTexturePVRTCName,
- WebGLCompressedTextureS3TCName,
- WebGLDebugRendererInfoName,
- WebGLDebugShadersName,
- WebGLDepthTextureName,
- WebGLDrawBuffersName,
- WebGLLoseContextName,
- };
-
- WebGLRenderingContext* context() { return m_context; }
+ WebGLRenderingContextBase* context() { return m_context; }
virtual ~WebGLExtension();
- virtual ExtensionName getName() const = 0;
+ virtual WebGLExtensionName getName() const = 0;
// Lose this extension. Passing true = force loss. Some extensions
// like WEBGL_lose_context are not normally lost when the context
// is lost but must be lost when destroying their WebGLRenderingContext.
virtual void lose(bool)
{
m_context = 0;
@@ -75,9 +54,9 @@ public:
}
protected:
- WebGLExtension(WebGLRenderingContext*);
+ WebGLExtension(WebGLRenderingContextBase*);
- WebGLRenderingContext* m_context;
+ WebGLRenderingContextBase* m_context;
};
} // namespace WebCore
@@ -34,36 +35,14 @@ namespace WebCore {
// Lose this extension. Passing true = force loss. Some extensions
// like WEBGL_lose_context are not normally lost when the context
- // is lost but must be lost when destroying their WebGLRenderingContext.
+ // is lost but must be lost when destroying their WebGLRenderingContextBase.
virtual void lose(bool)
{

Powered by Google App Engine
This is Rietveld 408576698